@@ -1,4 +1,6 @@
-from typing import cast
+import inspect
+from functools import partial
+from typing import cast, List, Type
 
 from pyfileconf.sectionpath.sectionpath import SectionPath
 from pyfileconf.selector.logic.exc.typo import (
@@ -20,6 +22,7 @@ class ItemView:
 
     def __init__(self, section_path_str: str, selector: Selector):
         self.section_path_str = section_path_str
+        self._section_path_str = section_path_str  # for compatibility with real items which have this attribute added
         self.selector = selector
         self._is_item_view = True
 
@@ -71,6 +74,7 @@ class ItemView:
             'section_path_str',
             'selector',
             '_is_item_view',
+            '_section_path_str',
         ]
         if key in item_view_set_attrs:
             super().__setattr__(key, value)
@@ -91,7 +95,12 @@ class ItemView:
         actual_item = self.selector._get_real_item(self.section_path_str)
         # If this happened while running another item, add to dependencies
         self._add_to_config_dependencies_if_necessary()
-        return actual_item(*args, **kwargs)
+        result = actual_item(*args, **kwargs)
+        if isinstance(actual_item, partial) and inspect.isclass(actual_item.func):
+            # Got a class in the general collection, running these generates
+            # an instance of the object so add the section path in this case
+            result._section_path_str = self.section_path_str
+        return result
 
     def __deepcopy__(self, memodict={}):
         return deepcopy(self.item, memodict)
@@ -124,17 +133,9 @@ class ItemView:
     def item(self):
         return self.selector._get_real_item(self.section_path_str)
 
-    def _add_to_config_dependencies(self):
-        from pyfileconf.main import PipelineManager
-        running_sp = SectionPath(PipelineManager._currently_running_section_path_str)
-        PipelineManager._config_attribute_dependencies[self.section_path_str].add(running_sp)
-        PipelineManager.config_dependencies[self.section_path_str].add(running_sp)
-
     def _add_to_config_dependencies_if_necessary(self):
-        from pyfileconf.main import PipelineManager
-        # If this happened while running another item, add to dependencies
-        if PipelineManager._currently_running_section_path_str is not None:
-            self._add_to_config_dependencies()
+        from pyfileconf.context import context
+        context.add_config_dependency_for_currently_running_item_if_exists(self.section_path_str, force_update=True)
 
 
 def _is_item_view(obj) -> bool:
