@@ -3,6 +3,7 @@ from copy import deepcopy
 
 from pyfileconf import Selector, PipelineManager
 from pyfileconf.sectionpath.sectionpath import SectionPath
+from pyfileconf.context import context
 from tests.input_files.amodule import SecondExampleClass
 from tests.input_files.mypackage.cmodule import ExampleClass
 from tests.test_pipeline_manager.base import PipelineManagerTestBase, CLASS_CONFIG_DICT_LIST, SAME_CLASS_CONFIG_DICT_LIST, \
@@ -106,7 +107,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         result = pipeline_manager.run(iv2)
         assert result == (None, iv2)
         assert result[1]() == (None, expected_b_result)
-        assert PipelineManager.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
+        assert context.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
 
     def test_config_update_function_dependencies(self):
         self.write_a_function_to_pipeline_dict_file()
@@ -123,7 +124,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
             section_path_str='stuff.a_function',
             b=sel.test_pipeline_manager2.stuff.a_function
         )
-        assert PipelineManager.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
+        assert context.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
 
     def test_config_update_class(self):
         self.write_example_class_to_pipeline_dict_file()
@@ -224,7 +225,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         ec = sel.test_pipeline_manager.stuff.ExampleClass()
         assert ec == expect_1
         assert ec.a().a == expected_a_result
-        assert PipelineManager.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
+        assert context.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
 
     def test_config_update_class_dependencies(self):
         self.write_example_class_to_pipeline_dict_file()
@@ -241,7 +242,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
             section_path_str='stuff.ExampleClass',
             a=sel.test_pipeline_manager2.stuff.ExampleClass
         )
-        assert PipelineManager.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
+        assert context.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
 
 
     def test_create_update_from_specific_class_dict(self):
@@ -361,7 +362,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         ec = sel.test_pipeline_manager.example_class.stuff.data.item
         assert ec == expect_1
         assert ec.a.a == expected_a_result
-        assert PipelineManager.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
+        assert context.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
 
     def test_create_update_specific_class_dependencies(self):
         self.write_example_class_dict_to_file()
@@ -381,7 +382,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
             section_path_str='example_class.stuff.data',
             a=sel.test_pipeline_manager2.example_class.stuff.data,
         )
-        assert PipelineManager.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
+        assert context.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
 
     def test_create_update_from_specific_class_dict_multiple_dependent_attribute_pms(self):
         self.write_example_class_dict_to_file()
@@ -420,7 +421,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         ec = sel.test_pipeline_manager.example_class.stuff.data.item
         assert ec == expect_1
         assert ec.a == expected_a_result
-        assert PipelineManager.config_dependencies == PipelineManager._config_attribute_dependencies == \
+        assert context.config_dependencies == context.force_update_dependencies == \
                self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
 
     def test_create_update_from_multiple_specific_class_dicts_same(self):
@@ -686,7 +687,7 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         assert result_none is None
         assert result_sc.name == sc.name == expect_sc.name
         assert result_sc.a == sc.a == expect_sc.a
-        assert PipelineManager.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_1_specific_class
+        assert context.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_1_specific_class
 
     def test_config_update_function_by_item_view(self):
         self.write_a_function_to_pipeline_dict_file()
